import * as i0 from '@angular/core';
import { EventEmitter, Component, Optional, Self, Attribute, Input, HostBinding, Output, HostListener, NgModule } from '@angular/core';
import * as i1 from '@angular/forms';
import { Validators, ReactiveFormsModule } from '@angular/forms';
import { coerceBooleanProperty, coerceArray } from '@angular/cdk/coercion';
import * as i3 from '@angular/material/core';
import { mixinTabIndex, mixinDisabled, mixinErrorState } from '@angular/material/core';
import * as i6 from '@angular/material/datepicker';
import { MatDatepicker, MatDatepickerModule } from '@angular/material/datepicker';
import { MatFormFieldControl, MatFormFieldModule } from '@angular/material/form-field';
import { Subject } from 'rxjs';
import { takeUntil } from 'rxjs/operators';
import * as i2 from '@angular/cdk/a11y';
import * as i4 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i5 from '@angular/material/chips';
import { MatChipsModule } from '@angular/material/chips';
import * as i7 from '@angular/material/icon';
import { MatIconModule } from '@angular/material/icon';
import * as i8 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';

/* eslint-disable max-classes-per-file */
class MultipleDatesBaseMixinBase {
    constructor($elementRef, _defaultErrorStateMatcher, _parentForm, _parentFormGroup, ngControl) {
        this.$elementRef = $elementRef;
        this._defaultErrorStateMatcher = _defaultErrorStateMatcher;
        this._parentForm = _parentForm;
        this._parentFormGroup = _parentFormGroup;
        this.ngControl = ngControl;
        /**
         * Stream that emits whenever the state of the control changes such that the parent
         * `MatFormField` needs to run change detection.
         */
        this.stateChanges = new Subject();
    }
}
const _MultipleDatesBaseMixinBase = mixinTabIndex(mixinDisabled(mixinErrorState(MultipleDatesBaseMixinBase)));
/**
 * Multiple dates component.
 * @template D Date type.
 */
class MultipleDatesComponent extends _MultipleDatesBaseMixinBase {
    /**
     * Creates an instance of MultipleDatesComponent.
     * @param ngControl Form control to manage component.
     * @param $elementRef A wrapper around a native element inside of a View.
     * @param _changeDetectorRef Base class that provides change detection functionality.
     * @param _focusMonitor Monitors mouse and keyboard events to determine the cause of focus events.
     * @param _dateAdapter Adapts type `D` to be usable as a date by cdk-based components that work
     * with dates.
     * @param parentForm Parent form.
     * @param parentFormGroup Parent form group.
     * @param defaultErrorStateMatcher Provider that defines how form controls behave with regards to
     * displaying error messages.
     * @param tabIndex Tab index.
     */
    constructor(ngControl, $elementRef, _changeDetectorRef, _focusMonitor, _dateAdapter, parentForm, parentFormGroup, defaultErrorStateMatcher, tabIndex) {
        super($elementRef, defaultErrorStateMatcher, parentForm, parentFormGroup, ngControl);
        this.ngControl = ngControl;
        this.$elementRef = $elementRef;
        this._changeDetectorRef = _changeDetectorRef;
        this._focusMonitor = _focusMonitor;
        this._dateAdapter = _dateAdapter;
        /** Unique id of the element. */
        this.id = `ngx-multiple-dates-${MultipleDatesComponent.nextId++}`;
        this.describedBy = '';
        /** Whether the control is in an error state. */
        this.errorState = false;
        /** Emits when a change event is fired on this `ngx-multiple-dates` element. */
        this.dateChange = new EventEmitter();
        /** Whether `ngx-multiple-dates` element has focus. */
        this.focused = false;
        /** A name for this control that can be used by mat-form-field. */
        this.controlType = 'ngx-multiple-dates';
        this._destroy = new Subject();
        /** Whether datepicker should be closed on date selected, or opened to select more dates. */
        this._closeOnSelected = false;
        /** Whether the component is required. */
        this._required = false;
        /** Whether the component is disabled. */
        this._disabled = false;
        /** The value of the `ngx-multiple-dates` control. */
        this._value = [];
        /** Theme color palette for the component. */
        this._color = null;
        /** Custom date classes. */
        this._classes = [];
        this._onChange = () => { };
        this._onTouched = () => { };
        this._onValidatorChange = () => { };
        this._filterValidator = (control) => {
            const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
            return !this._dateFilter || !value || this._dateFilter(value)
                ? null
                : { matDatepickerFilter: true };
        };
        this._minValidator = (control) => {
            const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
            return (!this.min || !value || this._dateAdapter.compareDate(this.min, value) <= 0)
                ? null
                : { matDatepickerMin: { min: this.min, actual: value } };
        };
        this._maxValidator = (control) => {
            const value = this._getValidDateOrNull(this._dateAdapter.deserialize(control.value));
            return (!this.max || !value || this._dateAdapter.compareDate(this.max, value) >= 0)
                ? null
                : { matDatepickerMax: { max: this.max, actual: value } };
        };
        /**
         * Function used to add CSS classes to selected dates.
         * @param date Date to check if classes should be applied.
         * @returns CSS classes to apply.
         */
        this.dateClass = (date) => {
            let className;
            if (this.classes.length) {
                className = this.getClassName(date);
            }
            if (this._find(date) !== -1) {
                return ['selected', ...(className ? [className] : [])];
            }
            if (className) {
                return [className];
            }
            return [];
        };
        this.resetModel = _dateAdapter.createDate(0, 0, 1);
        const validators = [
            this._filterValidator,
            this._minValidator,
            this._maxValidator
        ];
        if (this.ngControl != null) {
            this.ngControl.valueAccessor = this;
            if (this.ngControl.validator) {
                validators.push(this.ngControl.validator);
            }
        }
        this._validator = Validators.compose(validators);
        _focusMonitor.monitor($elementRef.nativeElement, true)
            .subscribe((origin) => {
            this.focused = !!origin;
            this.stateChanges.next();
        });
        this.tabIndex = Number(tabIndex) || 0;
    }
    /** The datepicker that this `ngx-multiple-dates` element is associated with. */
    get matDatepicker() {
        return this._matDatepicker;
    }
    set matDatepicker(value) {
        if (!value || !(value instanceof MatDatepicker)) {
            throw new TypeError(`"matDatepicker" attribute of "ngx-multiple-dates" is required and should be an instance of
        Angular Material Datepicker component.`);
        }
        this._matDatepicker = value;
        this.matDatepicker.closedStream
            .pipe(takeUntil(this._destroy))
            .subscribe(() => this.blur());
        if (!this.matDatepicker.startAt) {
            this._setStartAt();
        }
        this._setDisabled();
        this._setDateClass();
    }
    /** Whether datepicker should be closed on date selected, or opened to select more dates. */
    get closeOnSelected() {
        return this._closeOnSelected;
    }
    set closeOnSelected(value) {
        this._closeOnSelected = coerceBooleanProperty(value);
    }
    /** Placeholder to be shown if no value has been selected. */
    get placeholder() {
        return this._placeholder;
    }
    set placeholder(value) {
        this._placeholder = value;
        this.stateChanges.next();
    }
    /** Whether the component is required. */
    get required() {
        return this._required;
    }
    set required(value) {
        this._required = coerceBooleanProperty(value);
        this.stateChanges.next();
    }
    /** Whether the component is disabled. */
    get disabled() {
        // if (this.ngControl && this.ngControl.disabled !== null) {
        //   return this.ngControl.disabled;
        // }
        return this._disabled;
    }
    set disabled(value) {
        this._disabled = coerceBooleanProperty(value);
        this._setDisabled();
        if (this.focused) {
            this.focused = false;
            this.stateChanges.next();
        }
    }
    /** The value of the `ngx-multiple-dates` control. */
    get value() {
        if (!this._value) {
            this._value = [];
        }
        return this._value;
    }
    set value(value) {
        if (value !== this._value) {
            this.writeValue(value);
        }
    }
    /** Theme color palette for the component. */
    get color() {
        return this._color;
    }
    set color(value) {
        this._color = value;
    }
    /** Function that can be used to filter out dates within the datepicker. */
    get matDatepickerFilter() {
        return this._dateFilter;
    }
    set matDatepickerFilter(value) {
        this._dateFilter = value;
        this._onValidatorChange();
    }
    /** The minimum valid date. */
    get min() {
        return this._min;
    }
    set min(value) {
        this._min = this._getValidDateOrNull(this._dateAdapter.deserialize(value));
        this._onValidatorChange();
    }
    /** The maximum valid date. */
    get max() {
        return this._max;
    }
    set max(value) {
        this._max = this._getValidDateOrNull(this._dateAdapter.deserialize(value));
        this._onValidatorChange();
    }
    /** Custom date classes. */
    get classes() {
        return this._classes;
    }
    set classes(value) {
        this._classes = coerceArray(value);
    }
    /** Whether the `MatFormField` label should try to float. */
    get shouldLabelFloat() {
        return !this.empty || (this.focused && !this.disabled);
    }
    /** Whether the select has a value. */
    get empty() {
        return !this.value || !this.value.length;
    }
    ngAfterViewInit() {
        if (this.ngControl && this.ngControl.control) {
            this.ngControl.control.setValidators(this.validate.bind(this));
        }
        this._setStartAt();
        this._setDateClass();
    }
    ngOnDestroy() {
        this._destroy.next();
        this._destroy.complete();
        this.stateChanges.complete();
        this._focusMonitor.stopMonitoring(this.$elementRef.nativeElement);
    }
    ngDoCheck() {
        if (this.ngControl) {
            this.updateErrorState();
        }
    }
    /** Focuses the `ngx-multiple-dates` element. */
    focus() {
        if (!this.disabled) {
            this.focused = true;
            if (this.matDatepicker) {
                this.matDatepicker.open();
            }
            // this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
        }
    }
    /** Used to leave focus from the `ngx-multiple-dates` element. */
    blur() {
        this.focused = false;
        if (!this.disabled) {
            this._onTouched();
            // if (this.matDatepicker && this.matDatepicker.opened) {
            //   this.matDatepicker.close();
            // }
            this._changeDetectorRef.markForCheck();
            this.stateChanges.next();
        }
    }
    writeValue(value) {
        if (Array.isArray(value)) {
            this._value = [...value];
            this._sort();
        }
        else {
            this._value = value;
        }
        this._onChange(value);
        this.stateChanges.next();
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._onTouched = fn;
    }
    registerOnValidatorChange(fn) {
        this._onValidatorChange = fn;
    }
    /**
     * Sets the list of element IDs that currently describe this control.
     * @param ids Ids to set.
     */
    setDescribedByIds(ids) {
        this.describedBy = ids.join(' ');
    }
    /** Handles a click on the control's container. */
    onContainerClick() {
        if (!this.focused) {
            this.focus();
        }
    }
    /**
     * Performs synchronous validation for the control.
     * @param control The control to validate against.
     * @returns A map of validation errors if validation fails, otherwise null.
     */
    validate(control) {
        return this._validator ? this._validator(control) : null;
    }
    /**
     * Fires when a change event is fired on the datepicker `<input />`.
     * @param event Change event.
     */
    dateChanged(event) {
        if (event.value) {
            const date = event.value;
            if (this.value) {
                const index = this._find(date);
                if (index === -1) {
                    this.value.push(date);
                    this._sort();
                }
                else {
                    this.value.splice(index, 1);
                }
            }
            this.resetModel = this._dateAdapter.createDate(0, 0, 1);
            this._setStartAt();
            if (this.matDatepicker && !this.closeOnSelected) {
                const closeFn = this.matDatepicker.close;
                this.matDatepicker.close = () => { };
                this.matDatepicker['_componentRef'].instance._calendar.monthView._createWeekCells();
                setTimeout(() => this.matDatepicker.close = closeFn);
                this._changeDetectorRef.detectChanges();
            }
            this.writeValue(this.value);
        }
        this.dateChange.emit(event);
    }
    /**
     * Removes selected chip from the list.
     * @param date Value to remove.
     */
    remove(date) {
        if (this.value && this.value.length) {
            this._onTouched();
            const index = this._find(date);
            this.value.splice(index, 1);
            this.writeValue(this.value);
            this._changeDetectorRef.detectChanges();
        }
    }
    trackByValue(_index, item) {
        return item;
    }
    getClassName(value) {
        for (const classValue of this.classes) {
            if (this._dateAdapter.compareDate(classValue.value, value) === 0) {
                return classValue.className;
            }
        }
        return undefined;
    }
    _setStartAt() {
        if (this.matDatepicker) {
            if (this.value && this.value.length) {
                this.matDatepicker.startAt = this.value[this.value.length - 1];
            }
            else {
                this.matDatepicker.startAt = this._dateAdapter.today();
            }
        }
    }
    _setDisabled() {
        if (this.matDatepicker) {
            this.matDatepicker.disabled = this.disabled;
        }
    }
    _setDateClass() {
        if (this.matDatepicker) {
            const dateClassFn = this.matDatepicker.dateClass;
            this.matDatepicker.dateClass = (date) => {
                const classList = this.dateClass(date);
                if (dateClassFn) {
                    const oldClasses = dateClassFn(date, 'month');
                    if (classList.length) {
                        if (oldClasses instanceof Set) {
                            for (const className of classList) {
                                oldClasses.add(className);
                            }
                        }
                        else if (oldClasses instanceof Array) {
                            for (const className of classList) {
                                oldClasses.push(className);
                            }
                        }
                        else if (typeof ('t') === 'string') {
                            return [oldClasses, ...classList].join(' ');
                        }
                        else {
                            for (const className of classList) {
                                oldClasses[className] = className;
                            }
                        }
                        return oldClasses;
                    }
                    return oldClasses;
                }
                return classList;
            };
        }
    }
    _find(date) {
        if (!this.value) {
            return -1;
        }
        return this.value.map((value) => this._dateAdapter.compareDate(value, date)).indexOf(0);
    }
    _sort() {
        if (this.value) {
            this.value.sort((lhs, rhs) => this._dateAdapter.compareDate(lhs, rhs));
        }
    }
    _getValidDateOrNull(obj) {
        return (this._dateAdapter.isDateInstance(obj) && this._dateAdapter.isValid(obj)) ? obj : null;
    }
}
MultipleDatesComponent.nextId = 0;
MultipleDatesComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: MultipleDatesComponent, deps: [{ token: i1.NgControl, optional: true, self: true }, { token: i0.ElementRef }, { token: i0.ChangeDetectorRef }, { token: i2.FocusMonitor }, { token: i3.DateAdapter }, { token: i1.NgForm, optional: true }, { token: i1.FormGroupDirective, optional: true }, { token: i3.ErrorStateMatcher }, { token: 'tabindex', attribute: true }], target: i0.ɵɵFactoryTarget.Component });
MultipleDatesComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "14.0.0-next.15", type: MultipleDatesComponent, selector: "ngx-multiple-dates", inputs: { id: "id", errorStateMatcher: "errorStateMatcher", tabIndex: "tabIndex", format: "format", matDatepicker: "matDatepicker", closeOnSelected: "closeOnSelected", placeholder: "placeholder", required: "required", disabled: "disabled", value: "value", color: "color", matDatepickerFilter: "matDatepickerFilter", min: "min", max: "max", classes: "classes" }, outputs: { dateChange: "dateChange" }, host: { listeners: { "focus": "focus()", "blur": "blur()" }, properties: { "id": "this.id", "attr.aria-describedby": "this.describedBy", "attr.aria-invalid": "this.errorState", "class.mat-form-field-invalid": "this.errorState", "attr.tabindex": "this.tabIndex", "attr.aria-label": "this.placeholder", "attr.aria-required": "this.required", "attr.disabled": "this.disabled", "class.floating": "this.shouldLabelFloat" } }, providers: [
        { provide: MatFormFieldControl, useExisting: MultipleDatesComponent }
    ], exportAs: ["ngxMultipleDates"], usesInheritance: true, ngImport: i0, template: "<mat-chip-list #chipList aria-label=\"placeholder\" [selectable]=\"false\"\r\n               (click)=\"focus()\">\r\n  <mat-chip *ngFor=\"let item of value; trackBy: trackByValue;\" removable (removed)=\"remove(item)\"\r\n            [color]=\"color\" [selected]=\"color\" [ngClass]='getClassName(item)'>\r\n    {{ item | date : format }}\r\n    <mat-icon matChipRemove>cancel</mat-icon>\r\n  </mat-chip>\r\n  <input matInput hidden [value]=\"resetModel\"\r\n         [matDatepicker]=\"matDatepicker\" [matDatepickerFilter]=\"matDatepickerFilter\"\r\n         [min]=\"min\" [max]=\"max\" [matChipInputFor]=\"chipList\" (dateChange)=\"dateChanged($event)\" />\r\n</mat-chip-list>\r\n", styles: [":host{display:block;outline:none!important}:host span{opacity:0;transition:opacity .2s}:host.floating span{opacity:1}:host ::ng-deep mat-chip-list{outline:none!important}:host ::ng-deep mat-chip-list .mat-chip-list-wrapper{min-height:18px}:host ::ng-deep mat-chip-list .mat-chip-remove{outline:none!important}\n"], dependencies: [{ kind: "directive", type: i4.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i4.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: i5.MatChipList, selector: "mat-chip-list", inputs: ["role", "aria-describedby", "errorStateMatcher", "multiple", "compareWith", "value", "required", "placeholder", "disabled", "aria-orientation", "selectable", "tabIndex"], outputs: ["change", "valueChange"], exportAs: ["matChipList"] }, { kind: "directive", type: i5.MatChip, selector: "mat-basic-chip, [mat-basic-chip], mat-chip, [mat-chip]", inputs: ["color", "disableRipple", "tabIndex", "role", "selected", "value", "selectable", "disabled", "removable"], outputs: ["selectionChange", "destroyed", "removed"], exportAs: ["matChip"] }, { kind: "directive", type: i5.MatChipInput, selector: "input[matChipInputFor]", inputs: ["matChipInputFor", "matChipInputAddOnBlur", "matChipInputSeparatorKeyCodes", "placeholder", "id", "disabled"], outputs: ["matChipInputTokenEnd"], exportAs: ["matChipInput", "matChipInputFor"] }, { kind: "directive", type: i5.MatChipRemove, selector: "[matChipRemove]" }, { kind: "directive", type: i6.MatDatepickerInput, selector: "input[matDatepicker]", inputs: ["matDatepicker", "min", "max", "matDatepickerFilter"], exportAs: ["matDatepickerInput"] }, { kind: "component", type: i7.MatIcon, selector: "mat-icon", inputs: ["color", "inline", "svgIcon", "fontSet", "fontIcon"], exportAs: ["matIcon"] }, { kind: "directive", type: i8.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }, { kind: "pipe", type: i4.DatePipe, name: "date" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: MultipleDatesComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-multiple-dates', providers: [
                        { provide: MatFormFieldControl, useExisting: MultipleDatesComponent }
                    ], exportAs: 'ngxMultipleDates', template: "<mat-chip-list #chipList aria-label=\"placeholder\" [selectable]=\"false\"\r\n               (click)=\"focus()\">\r\n  <mat-chip *ngFor=\"let item of value; trackBy: trackByValue;\" removable (removed)=\"remove(item)\"\r\n            [color]=\"color\" [selected]=\"color\" [ngClass]='getClassName(item)'>\r\n    {{ item | date : format }}\r\n    <mat-icon matChipRemove>cancel</mat-icon>\r\n  </mat-chip>\r\n  <input matInput hidden [value]=\"resetModel\"\r\n         [matDatepicker]=\"matDatepicker\" [matDatepickerFilter]=\"matDatepickerFilter\"\r\n         [min]=\"min\" [max]=\"max\" [matChipInputFor]=\"chipList\" (dateChange)=\"dateChanged($event)\" />\r\n</mat-chip-list>\r\n", styles: [":host{display:block;outline:none!important}:host span{opacity:0;transition:opacity .2s}:host.floating span{opacity:1}:host ::ng-deep mat-chip-list{outline:none!important}:host ::ng-deep mat-chip-list .mat-chip-list-wrapper{min-height:18px}:host ::ng-deep mat-chip-list .mat-chip-remove{outline:none!important}\n"] }]
        }], ctorParameters: function () {
        return [{ type: i1.NgControl, decorators: [{
                        type: Optional
                    }, {
                        type: Self
                    }] }, { type: i0.ElementRef }, { type: i0.ChangeDetectorRef }, { type: i2.FocusMonitor }, { type: i3.DateAdapter }, { type: i1.NgForm, decorators: [{
                        type: Optional
                    }] }, { type: i1.FormGroupDirective, decorators: [{
                        type: Optional
                    }] }, { type: i3.ErrorStateMatcher }, { type: undefined, decorators: [{
                        type: Attribute,
                        args: ['tabindex']
                    }] }];
    }, propDecorators: { id: [{
                type: Input
            }, {
                type: HostBinding
            }], describedBy: [{
                type: HostBinding,
                args: ['attr.aria-describedby']
            }], errorState: [{
                type: HostBinding,
                args: ['attr.aria-invalid']
            }, {
                type: HostBinding,
                args: ['class.mat-form-field-invalid']
            }], errorStateMatcher: [{
                type: Input
            }], tabIndex: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.tabindex']
            }], format: [{
                type: Input
            }], dateChange: [{
                type: Output
            }], matDatepicker: [{
                type: Input
            }], closeOnSelected: [{
                type: Input
            }], placeholder: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-label']
            }], required: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.aria-required']
            }], disabled: [{
                type: Input
            }, {
                type: HostBinding,
                args: ['attr.disabled']
            }], value: [{
                type: Input
            }], color: [{
                type: Input
            }], matDatepickerFilter: [{
                type: Input
            }], min: [{
                type: Input
            }], max: [{
                type: Input
            }], classes: [{
                type: Input
            }], shouldLabelFloat: [{
                type: HostBinding,
                args: ['class.floating']
            }], focus: [{
                type: HostListener,
                args: ['focus']
            }], blur: [{
                type: HostListener,
                args: ['blur']
            }] } });

/**
 * Date class item.
 * @template D Date type.
 */
class DateClass {
}

class NgxMultipleDatesModule {
}
NgxMultipleDatesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: NgxMultipleDatesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMultipleDatesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: NgxMultipleDatesModule, declarations: [MultipleDatesComponent], imports: [CommonModule,
        ReactiveFormsModule,
        MatChipsModule,
        MatDatepickerModule,
        MatFormFieldModule,
        MatIconModule,
        MatInputModule], exports: [MultipleDatesComponent] });
NgxMultipleDatesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: NgxMultipleDatesModule, imports: [CommonModule,
        ReactiveFormsModule,
        MatChipsModule,
        MatDatepickerModule,
        MatFormFieldModule,
        MatIconModule,
        MatInputModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.0.0-next.15", ngImport: i0, type: NgxMultipleDatesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MultipleDatesComponent],
                    imports: [
                        CommonModule,
                        ReactiveFormsModule,
                        MatChipsModule,
                        MatDatepickerModule,
                        MatFormFieldModule,
                        MatIconModule,
                        MatInputModule
                    ],
                    exports: [MultipleDatesComponent]
                }]
        }] });

/*
 * Public API Surface of ngx-multiple-dates
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DateClass, MultipleDatesComponent, NgxMultipleDatesModule };
//# sourceMappingURL=ngx-multiple-dates.mjs.map
