import { ChangeDetectorRef, AfterViewInit, OnDestroy, DoCheck, EventEmitter, ElementRef } from '@angular/core';
import { ControlValueAccessor, AbstractControl, NgControl, NgForm, FormGroupDirective, Validator, ValidationErrors } from '@angular/forms';
import { FocusMonitor } from '@angular/cdk/a11y';
import { DateAdapter, ThemePalette, CanUpdateErrorState, HasTabIndex, CanDisable, ErrorStateMatcher } from '@angular/material/core';
import { MatDatepicker, MatDatepickerInputEvent } from '@angular/material/datepicker';
import { MatFormFieldControl } from '@angular/material/form-field';
import { Subject } from 'rxjs';
import { DateClass } from '../../models/date-class.model';
import * as i0 from "@angular/core";
declare abstract class MultipleDatesBaseMixinBase {
    protected $elementRef: ElementRef<HTMLElement>;
    _defaultErrorStateMatcher: ErrorStateMatcher;
    _parentForm: NgForm;
    _parentFormGroup: FormGroupDirective;
    ngControl: NgControl;
    /**
     * Stream that emits whenever the state of the control changes such that the parent
     * `MatFormField` needs to run change detection.
     */
    readonly stateChanges: Subject<void>;
    constructor($elementRef: ElementRef<HTMLElement>, _defaultErrorStateMatcher: ErrorStateMatcher, _parentForm: NgForm, _parentFormGroup: FormGroupDirective, ngControl: NgControl);
}
declare const _MultipleDatesBaseMixinBase: import("@angular/material/core")._Constructor<HasTabIndex> & import("@angular/material/core")._AbstractConstructor<HasTabIndex> & import("@angular/material/core")._Constructor<CanDisable> & import("@angular/material/core")._AbstractConstructor<CanDisable> & import("@angular/material/core")._Constructor<CanUpdateErrorState> & import("@angular/material/core")._AbstractConstructor<CanUpdateErrorState> & typeof MultipleDatesBaseMixinBase;
/**
 * Multiple dates component.
 * @template D Date type.
 */
export declare class MultipleDatesComponent<D = Date> extends _MultipleDatesBaseMixinBase implements AfterViewInit, OnDestroy, DoCheck, ControlValueAccessor, MatFormFieldControl<D[]>, HasTabIndex, CanDisable, CanUpdateErrorState, Validator {
    ngControl: NgControl;
    protected $elementRef: ElementRef<HTMLElement>;
    private _changeDetectorRef;
    private _focusMonitor;
    private _dateAdapter;
    static nextId: number;
    /** Unique id of the element. */
    id: string;
    describedBy: string;
    /** Whether the control is in an error state. */
    errorState: boolean;
    /** An object used to control when error messages are shown. */
    errorStateMatcher: ErrorStateMatcher;
    tabIndex: number;
    /**
     * The date/time components to include, using predefined options or a custom format string.
     * @see {@link https://angular.io/api/common/DatePipe#usage-notes DatePipe Usage notes} for more
     * information.
     */
    readonly format?: string;
    /** Emits when a change event is fired on this `ngx-multiple-dates` element. */
    readonly dateChange: EventEmitter<MatDatepickerInputEvent<D, unknown>>;
    /** Whether `ngx-multiple-dates` element has focus. */
    focused: boolean;
    /** A name for this control that can be used by mat-form-field. */
    controlType?: string | undefined;
    /**
     * Model used to reset datepicker selected value, so unselect just selectad date will be
     * possible.
     */
    resetModel: D;
    private readonly _destroy;
    /** The datepicker that this `ngx-multiple-dates` element is associated with. */
    private _matDatepicker;
    /** Whether datepicker should be closed on date selected, or opened to select more dates. */
    private _closeOnSelected;
    /** Placeholder to be shown if no value has been selected. */
    private _placeholder;
    /** Whether the component is required. */
    private _required;
    /** Whether the component is disabled. */
    private _disabled;
    /** The value of the `ngx-multiple-dates` control. */
    private _value;
    /** Theme color palette for the component. */
    private _color;
    /** Function that can be used to filter out dates within the datepicker. */
    private _dateFilter;
    /** The minimum valid date. */
    private _min;
    /** The maximum valid date. */
    private _max;
    /** Custom date classes. */
    private _classes;
    private _validator;
    private _onChange;
    private _onTouched;
    private _onValidatorChange;
    private _filterValidator;
    private _minValidator;
    private _maxValidator;
    /** The datepicker that this `ngx-multiple-dates` element is associated with. */
    get matDatepicker(): MatDatepicker<D>;
    set matDatepicker(value: MatDatepicker<D>);
    /** Whether datepicker should be closed on date selected, or opened to select more dates. */
    get closeOnSelected(): boolean;
    set closeOnSelected(value: boolean);
    /** Placeholder to be shown if no value has been selected. */
    get placeholder(): string;
    set placeholder(value: string);
    /** Whether the component is required. */
    get required(): boolean;
    set required(value: boolean);
    /** Whether the component is disabled. */
    get disabled(): boolean;
    set disabled(value: boolean);
    /** The value of the `ngx-multiple-dates` control. */
    get value(): D[] | null;
    set value(value: D[] | null);
    /** Theme color palette for the component. */
    get color(): ThemePalette | null;
    set color(value: ThemePalette | null);
    /** Function that can be used to filter out dates within the datepicker. */
    get matDatepickerFilter(): (date: D | null) => boolean;
    set matDatepickerFilter(value: (date: D | null) => boolean);
    /** The minimum valid date. */
    get min(): D | null;
    set min(value: D | null);
    /** The maximum valid date. */
    get max(): D | null;
    set max(value: D | null);
    /** Custom date classes. */
    get classes(): Array<DateClass<D>>;
    set classes(value: Array<DateClass<D>>);
    /** Whether the `MatFormField` label should try to float. */
    get shouldLabelFloat(): boolean;
    /** Whether the select has a value. */
    get empty(): boolean;
    /**
     * Creates an instance of MultipleDatesComponent.
     * @param ngControl Form control to manage component.
     * @param $elementRef A wrapper around a native element inside of a View.
     * @param _changeDetectorRef Base class that provides change detection functionality.
     * @param _focusMonitor Monitors mouse and keyboard events to determine the cause of focus events.
     * @param _dateAdapter Adapts type `D` to be usable as a date by cdk-based components that work
     * with dates.
     * @param parentForm Parent form.
     * @param parentFormGroup Parent form group.
     * @param defaultErrorStateMatcher Provider that defines how form controls behave with regards to
     * displaying error messages.
     * @param tabIndex Tab index.
     */
    constructor(ngControl: NgControl, $elementRef: ElementRef<HTMLElement>, _changeDetectorRef: ChangeDetectorRef, _focusMonitor: FocusMonitor, _dateAdapter: DateAdapter<D>, parentForm: NgForm, parentFormGroup: FormGroupDirective, defaultErrorStateMatcher: ErrorStateMatcher, tabIndex: string);
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    ngDoCheck(): void;
    /** Focuses the `ngx-multiple-dates` element. */
    focus(): void;
    /** Used to leave focus from the `ngx-multiple-dates` element. */
    blur(): void;
    writeValue(value: D[] | null): void;
    registerOnChange(fn: (_: any) => void): void;
    registerOnTouched(fn: () => void): void;
    registerOnValidatorChange(fn: () => void): void;
    /**
     * Sets the list of element IDs that currently describe this control.
     * @param ids Ids to set.
     */
    setDescribedByIds(ids: string[]): void;
    /** Handles a click on the control's container. */
    onContainerClick(): void;
    /**
     * Performs synchronous validation for the control.
     * @param control The control to validate against.
     * @returns A map of validation errors if validation fails, otherwise null.
     */
    validate(control: AbstractControl): ValidationErrors | null;
    /**
     * Function used to add CSS classes to selected dates.
     * @param date Date to check if classes should be applied.
     * @returns CSS classes to apply.
     */
    dateClass: (date: D) => string[];
    /**
     * Fires when a change event is fired on the datepicker `<input />`.
     * @param event Change event.
     */
    dateChanged(event: MatDatepickerInputEvent<D>): void;
    /**
     * Removes selected chip from the list.
     * @param date Value to remove.
     */
    remove(date: D): void;
    trackByValue(_index: number, item: D): D;
    getClassName(value: D): string | undefined;
    private _setStartAt;
    private _setDisabled;
    private _setDateClass;
    private _find;
    private _sort;
    private _getValidDateOrNull;
    static ɵfac: i0.ɵɵFactoryDeclaration<MultipleDatesComponent<any>, [{ optional: true; self: true; }, null, null, null, null, { optional: true; }, { optional: true; }, null, { attribute: "tabindex"; }]>;
    static ɵcmp: i0.ɵɵComponentDeclaration<MultipleDatesComponent<any>, "ngx-multiple-dates", ["ngxMultipleDates"], { "id": "id"; "errorStateMatcher": "errorStateMatcher"; "tabIndex": "tabIndex"; "format": "format"; "matDatepicker": "matDatepicker"; "closeOnSelected": "closeOnSelected"; "placeholder": "placeholder"; "required": "required"; "disabled": "disabled"; "value": "value"; "color": "color"; "matDatepickerFilter": "matDatepickerFilter"; "min": "min"; "max": "max"; "classes": "classes"; }, { "dateChange": "dateChange"; }, never, never, false>;
}
export {};
